#
# spec file for package spirv-cross
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define lname libspirv-cross-c-shared0
%define __builder ninja
Name:           spirv-cross
Version:        1.3.275.0
Release:        3.1
Summary:        Tool and library for SPIR-V reflection and disassembly
License:        Apache-2.0 OR MIT
Group:          Development/Libraries/C and C++
URL:            https://github.com/KhronosGroup/SPIRV-Cross
Source0:        https://github.com/KhronosGroup/SPIRV-Cross/archive/vulkan-sdk-%version.tar.gz
BuildRequires:  c++_compiler
BuildRequires:  cmake >= 3
BuildRequires:  ninja
BuildRequires:  pkg-config

%description
SPIRV-Cross is a tool and library designed for parsing and
converting SPIR-V to other shader languages.

Features:
  * Conversion of SPIR-V to GLSL, MSL or HLSL
  * Conversion of SPIR-V to a JSON reflection format
  * Reflection API to simplify the creation of Vulkan pipeline
    layouts
  * Reflection API to modify and tweak OpDecorations
  * Support for "all" of vertex, fragment, tessellation, geometry
    and compute shaders.

%package -n %lname
Summary:        Library for SPIR-V reflection and disassembly
Group:          System/Libraries

%description -n %lname
SPIRV-Cross is a tool and library designed for parsing and
converting SPIR-V to other shader languages.

%package devel
Summary:        Development headers for the SPIRV-Cross library
Group:          Development/Libraries/C and C++
Requires:       %lname = %version-%release
Obsoletes:      libspirv-cross-c-shared-devel < %version-%release
Provides:       libspirv-cross-c-shared-devel = %version-%release

%description devel
SPIRV-Cross is a tool and library designed for parsing and
converting SPIR-V to other shader languages.

%prep
%autosetup -p1 -n SPIRV-Cross-vulkan-sdk-%version
sed -i 's,$CMAKE_INSTALL_PREFIX/lib,%_libdir,;s,/share/pkgconfig,/%_lib/pkgconfig,;s,DESTINATION lib,DESTINATION %_lib,g' CMakeLists.txt

%build
%cmake \
    -DSPIRV_CROSS_SHARED=ON \
    -DSPIRV_CROSS_CLI=ON
%cmake_build

%install
%cmake_install
rm -fv %buildroot/%_libdir/*.a
# When static/shared library names aren't thought through...
for i in c core cpp glsl hlsl msl reflect util; do
	ln -s "libspirv-cross-c-shared.so" "%buildroot/%_libdir/libspirv-cross-$i.so"
done

%post   -n %lname -p /sbin/ldconfig
%postun -n %lname -p /sbin/ldconfig

%files
%license LICENSE
%doc README.md
%_bindir/spirv-cross

%files -n %lname
%_libdir/libspirv-cross-c-shared.so.*

%files devel
%_libdir/libspirv-cross-*.so
%_libdir/pkgconfig/*.pc
%_includedir/spirv_cross
%dir %_datadir/spirv*
%_datadir/spirv*/cmake/

%changelog
* Tue Jan 30 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release SDK-1.3.275.0
  * MSL: Support std140 half matrices and arrays.
  * HLSL: Fix issue with vec4 straddle rules in substructs.
* Fri Oct 27 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release SDK-1.3.268.0
  * GLSL: Implement 64-bit image support.
  * GLSL: Handle empty block declarations.
* Fri Aug 25 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release SDK-1.3.261.0
  * GLSL: Support KHR_subgroup_arithmetic IAdd/FAdd/IMul/FMul
  * HLSL: support Texture2D::GatherCmp function
  * HLSL: Add support to preserve (RW)StructuredBuffer resources
  * HLSL: Add CLI option for --hlsl-preserve-structured-buffers
  * MSL: Consider bool/short remapping when dealing with composites
  * MSL: Handle more complex array copy scenarios with bool <-> short
  * MSL: Support `SPV_KHR_shader_ballot` and `SPV_KHR_subgroup_vote`
* Wed Mar 29 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release SDK-1.3.243.0
  * Add C API option for enabling row-major workaround.
  * Add tests for loops compiled with debug semantics.
  * GLSL/HLSL: Add legacy handling for int vertex attributes
  * GLSL: Support GL_NV_shader_noperspective_interpolation in GLES
  * GLSL: Multiplying matrix with scalar shouldn't force transpose
  * GLSL: Add various additional extension checks.
  * GLSL: Allow sample inputs in desktop < 400 with
    GL_ARB_sample_shading
  * GLSL: Add support for modf, isnan and isinf in legacy GLSL
  * GLSL/HLSL: Add emulated fallbacks for
    sinh/cosh/tanh/asinh/acosh/atanh
  * GLSL: Legacy matrix inverse/determinant polyfills,
    outerProduct()
* Tue Jan  3 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.3.236.0
  * MSL: Support "raw" buffer input in tessellation evaluation
    shaders.
  * MSL: Handle partial access chains with array-of-UBO/SSBO.
  * HLSL: Implement VK_EXT_mesh_shader
* Mon Oct 24 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.3.231.0
  * GLSL: disable row major load around on GLES.
  * GLSL: added an option to disable row-major-load workaround.
  * GLSL: Implement GL_EXT_mesh_shader.
  * GLSL: Implement task shaders.
  * GLSL: Account for ES sampler1D to sampler2D promotion in
    textureSize.
  * MSL: Report unsupported 64-bit atomics.
  * Add reflection support for shader record buffers.
* Wed Jun 15 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.3.216.0
  * GLSL, HLSL: Support logical subgroup ops.
  * Support reflecting builtins.
  * GLSL: Support GL_EXT_shader_image_load_formatted.
  * GLSL: Implement gl_FragFullyCoveredNV and control flow hints.
  * Handle SPIR-V 1.4 selection constructs.
  * GLSL: Support pervertexNV in NV barycentric extension.
  * GLSL: Implement GL_EXT_ray_query.
  * MSL: Support row-major transpose when storing matrix from
    constant RHS matrix.
  * Add support for additional ops in OpSpecConstantOp.
  * Add 64 bit support for OpSwitch
  * HLSL: Add support for gl_HelperInvocation
  * VK_KHR_ray_query implementation
- Use an SRPM-based name for the -devel subpackage.
* Fri Jan 15 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 2020-01-25
  * GLSL: Support both SPV_KHR_ray_tracing and NV_ray_tracing.
  * Support pull-model interpolation on MSL 2.3+.
* Tue Jul  7 2020 Mia Herkt <mia@0x0.st>
- Update to 2020-06-29 (no changelog)
* Thu May 21 2020 Mia Herkt <mia@0x0.st>
- Update to 2020-05-19 (no changelog)
* Wed Apr  8 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 2020-04-03
  * MSL: Reintroduce workarounds for arrays not being value
    types.
  * Expose query if a resource was used as a comparison/depth
    resource.
* Sat Jan 18 2020 Martin Herkt <9+suse@cirno.systems>
- Update to 2020-01-16 (no changelog)
* Sat Aug 24 2019 Jan Engelhardt <jengelh@inai.de>
- Trim description for non-"main" (by importance) subpackages.
  Compact main description.
* Sun Aug 11 2019 Martin Herkt <9+suse@cirno.systems>
- Update to 2019-07-26
  * No upstream changelog
* Fri Jun 14 2019 Martin Herkt <9+suse@cirno.systems>
- Init, 2019-05-20
